==> cr12g-panhuo-api-3.0.0-20210510.094220-8-sources.jar: com/ejianc/business/asset/vo/CheckVO.java <==
package com.ejianc.business.asset.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 验收实体
 * 
 * @author generator
 * 
 */
public class CheckVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.String billCode; // 单据编号
    private java.lang.Long projectId; // 项目
    private java.lang.String projectName; // 项目名称
    private java.lang.Long orgId; // 组织
    private java.lang.String orgName; // 组织名称
    private java.lang.Long supplierId; // 设备供应商
    private java.lang.String supplierName; // 供应商名称
    private java.lang.String materialName; // 物资名称
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date checkDate; // 验收日期
    private java.lang.Long employeeId; // 经办人
    private java.lang.String employeeName; // 经办人名称
    private java.lang.Integer billState; // 单据状态（审批必须字段）
    private java.lang.String billStateName; // 单据状态（审批必须字段）
    private java.lang.Long createUserId; // 创建者主键
    private java.lang.String createUserSourceId; // 创建者来源ID
    private java.lang.String createUserName; // 创建者名称
    private java.lang.Long engineeringType; // 工程类型
    private java.lang.String engineeringTypeName; // 工程类型名称
    private java.lang.Integer checkType; // 验收类型(0-项目自采,1-内部调拨)
    private java.lang.String checkTypeName; // 验收类型(0-项目自采,1-内部调拨)
    private java.lang.String signerName; // 工地签收人
    private java.lang.Long allotId; // 调拨单主键
    private java.lang.Long checkId; // 验收人
    private java.lang.String checkName; // 验收人名称
    private java.lang.String allotCode; // 调拨单编号
    private java.lang.Long projectOutId; // 调出项目
    private java.lang.String projectOutName; // 调出项目名称
    private java.lang.Integer belongType; // 类型 0=项目，1=公司
    private java.lang.Long parentOrgId; // 上级组织id
    private java.lang.String parentOrgName; // 上级组织name

    public String getBillStateName() {
        return billStateName;
    }

    public void setBillStateName(String billStateName) {
        this.billStateName = billStateName;
    }

    public String getCheckTypeName() {
        return checkTypeName;
    }

    public void setCheckTypeName(String checkTypeName) {
        this.checkTypeName = checkTypeName;
    }

    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 组织
     */
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 组织
     */
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 设备供应商
     */
    public java.lang.Long getSupplierId() {
        return supplierId;
    }

    /**
     * 设备供应商
     */
    public void setSupplierId(java.lang.Long supplierId) {
        this.supplierId = supplierId;
    }
    /**
     * 供应商名称
     */
    public java.lang.String getSupplierName() {
        return supplierName;
    }

    /**
     * 供应商名称
     */
    public void setSupplierName(java.lang.String supplierName) {
        this.supplierName = supplierName;
    }
    /**
     * 物资名称
     */
    public java.lang.String getMaterialName() {
        return materialName;
    }

    /**
     * 物资名称
     */
    public void setMaterialName(java.lang.String materialName) {
        this.materialName = materialName;
    }
    /**
     * 验收日期
     */
    public java.util.Date getCheckDate() {
        return checkDate;
    }

    /**
     * 验收日期
     */
    public void setCheckDate(java.util.Date checkDate) {
        this.checkDate = checkDate;
    }
    /**
     * 经办人名称
     */
    public java.lang.String getEmployeeName() {
        return employeeName;
    }

    /**
     * 经办人名称
     */
    public void setEmployeeName(java.lang.String employeeName) {
        this.employeeName = employeeName;
    }
    /**
     * 单据状态（审批必须字段）
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态（审批必须字段）
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 创建者主键
     */
    public java.lang.Long getCreateUserId() {
        return createUserId;
    }

    /**
     * 创建者主键
     */
    public void setCreateUserId(java.lang.Long createUserId) {
        this.createUserId = createUserId;
    }
    /**
     * 创建者来源ID
     */
    public java.lang.String getCreateUserSourceId() {
        return createUserSourceId;
    }

    /**
     * 创建者来源ID
     */
    public void setCreateUserSourceId(java.lang.String createUserSourceId) {
        this.createUserSourceId = createUserSourceId;
    }
    /**
     * 创建者名称
     */
    public java.lang.String getCreateUserName() {
        return createUserName;
    }

    /**
     * 创建者名称
     */
    public void setCreateUserName(java.lang.String createUserName) {
        this.createUserName = createUserName;
    }
    /**
     * 工程类型
     */
    public java.lang.Long getEngineeringType() {
        return engineeringType;
    }

    /**
     * 工程类型
     */
    public void setEngineeringType(java.lang.Long engineeringType) {
        this.engineeringType = engineeringType;
    }
    /**
     * 工程类型名称
     */
    public java.lang.String getEngineeringTypeName() {
        return engineeringTypeName;
    }

    /**
     * 工程类型名称
     */
    public void setEngineeringTypeName(java.lang.String engineeringTypeName) {
        this.engineeringTypeName = engineeringTypeName;
    }
    /**
     * 验收类型(0-项目自采,1-内部调拨)
     */
    public java.lang.Integer getCheckType() {
        return checkType;
    }

    /**
     * 验收类型(0-项目自采,1-内部调拨)
     */
    public void setCheckType(java.lang.Integer checkType) {
        this.checkType = checkType;
    }
    /**
     * 工地签收人
     */
    public java.lang.String getSignerName() {
        return signerName;
    }

    /**
     * 工地签收人
     */
    public void setSignerName(java.lang.String signerName) {
        this.signerName = signerName;
    }
    /**
     * 调拨单主键
     */
    public java.lang.Long getAllotId() {
        return allotId;
    }

    /**
     * 调拨单主键
     */
    public void setAllotId(java.lang.Long allotId) {
        this.allotId = allotId;
    }
    /**
     * 验收人
     */
    @ReferSerialTransfer(referCode="idm-employee")
    public java.lang.Long getCheckId() {
        return checkId;
    }

    /**
     * 验收人
     */
    @ReferDeserialTransfer
    public void setCheckId(java.lang.Long checkId) {
        this.checkId = checkId;
    }
    /**
     * 验收人名称
     */
    public java.lang.String getCheckName() {
        return checkName;
    }

    /**
     * 验收人名称
     */
    public void setCheckName(java.lang.String checkName) {
        this.checkName = checkName;
    }
    /**
     * 调拨单编号
     */
    public java.lang.String getAllotCode() {
        return allotCode;
    }

    /**
     * 调拨单编号
     */
    public void setAllotCode(java.lang.String allotCode) {
        this.allotCode = allotCode;
    }
    /**
     * 调出项目
     */
    public java.lang.Long getProjectOutId() {
        return projectOutId;
    }

    /**
     * 调出项目
     */
    public void setProjectOutId(java.lang.Long projectOutId) {
        this.projectOutId = projectOutId;
    }
    /**
     * 调出项目名称
     */
    public java.lang.String getProjectOutName() {
        return projectOutName;
    }

    /**
     * 调出项目名称
     */
    public void setProjectOutName(java.lang.String projectOutName) {
        this.projectOutName = projectOutName;
    }
    /**
     * 类型 0=项目，1=公司
     */
    public java.lang.Integer getBelongType() {
        return belongType;
    }

    /**
     * 类型 0=项目，1=公司
     */
    public void setBelongType(java.lang.Integer belongType) {
        this.belongType = belongType;
    }
    /**
     * 上级组织id
     */
    public java.lang.Long getParentOrgId() {
        return parentOrgId;
    }

    /**
     * 上级组织id
     */
    public void setParentOrgId(java.lang.Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    /**
     * 上级组织name
     */
    public java.lang.String getParentOrgName() {
        return parentOrgName;
    }

    /**
     * 上级组织name
     */
    public void setParentOrgName(java.lang.String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    @ReferSerialTransfer(referCode="market-project")
    public Long getProjectId() {
        return projectId;
    }

    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    @ReferSerialTransfer(referCode="idm-employee")
    public Long getEmployeeId() {
        return employeeId;
    }

    @ReferDeserialTransfer
    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
}

==> cr12g-panhuo-api-3.0.0-20210602.092550-74-sources.jar: com/ejianc/business/asset/vo/CheckVO.java <==
package com.ejianc.business.asset.vo;

import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.ejianc.framework.skeleton.refer.annotation.ReferDeserialTransfer;
import com.ejianc.framework.skeleton.refer.annotation.ReferSerialTransfer;
import com.ejianc.framework.skeleton.template.BaseVO;
import com.fasterxml.jackson.annotation.JsonFormat;


/**
 * 验收实体
 * 
 * @author generator
 * 
 */
public class CheckVO extends BaseVO {
    private static final long serialVersionUID = 1L;
    
    private java.lang.String billCode; // 单据编号
    private java.lang.Long projectId; // 项目
    private java.lang.String projectName; // 项目名称
    private java.lang.Long orgId; // 组织
    private java.lang.String orgName; // 组织名称
    private java.lang.Long supplierId; // 设备供应商
    private java.lang.String supplierName; // 供应商名称
    private java.lang.String materialName; // 物资名称
    @JsonFormat(pattern = "yyyy-MM-dd", timezone = "GMT+8")
    private java.util.Date checkDate; // 验收日期
    private java.lang.Long employeeId; // 经办人
    private java.lang.String employeeName; // 经办人名称
    private java.lang.Integer billState; // 单据状态（审批必须字段）
    private java.lang.String billStateName; // 单据状态（审批必须字段）
    private java.lang.Long createUserId; // 创建者主键
    private java.lang.String createUserSourceId; // 创建者来源ID
    private java.lang.String createUserName; // 创建者名称
    private java.lang.Long engineeringType; // 工程类型
    private java.lang.String engineeringTypeName; // 工程类型名称
    private java.lang.Integer checkType; // 验收类型(0-项目自采,1-内部调拨)
    private java.lang.String checkTypeName; // 验收类型(0-项目自采,1-内部调拨)
    private java.lang.String signerName; // 工地签收人
    private java.lang.Long allotId; // 调拨单主键
    private java.lang.Long checkId; // 验收人
    private java.lang.String checkName; // 验收人名称
    private java.lang.String allotCode; // 调拨单编号
    private java.lang.Long projectOutId; // 调出项目
    private java.lang.String projectOutName; // 调出项目名称
    private java.lang.Integer belongType; // 类型 0=项目，1=公司
    private java.lang.Long parentOrgId; // 上级组织id
    private java.lang.String parentOrgName; // 上级组织name
    // 设备明细子表
    private List<CheckDetailVO> checkDetail = new ArrayList<>();

    public List<CheckDetailVO> getCheckDetail() {
        return checkDetail;
    }

    public void setCheckDetail(List<CheckDetailVO> checkDetail) {
        this.checkDetail = checkDetail;
    }

    public String getBillStateName() {
        return billStateName;
    }

    public void setBillStateName(String billStateName) {
        this.billStateName = billStateName;
    }

    public String getCheckTypeName() {
        return checkTypeName;
    }

    public void setCheckTypeName(String checkTypeName) {
        this.checkTypeName = checkTypeName;
    }

    /**
     * 单据编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 单据编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 项目名称
     */
    public java.lang.String getProjectName() {
        return projectName;
    }

    /**
     * 项目名称
     */
    public void setProjectName(java.lang.String projectName) {
        this.projectName = projectName;
    }
    /**
     * 组织
     */
    @ReferSerialTransfer(referCode="idm-org")
    public java.lang.Long getOrgId() {
        return orgId;
    }

    /**
     * 组织
     */
    @ReferDeserialTransfer
    public void setOrgId(java.lang.Long orgId) {
        this.orgId = orgId;
    }
    /**
     * 组织名称
     */
    public java.lang.String getOrgName() {
        return orgName;
    }

    /**
     * 组织名称
     */
    public void setOrgName(java.lang.String orgName) {
        this.orgName = orgName;
    }
    /**
     * 设备供应商
     */
    @ReferSerialTransfer(referCode="support-supplier")
    public java.lang.Long getSupplierId() {
        return supplierId;
    }

    /**
     * 设备供应商
     */
    @ReferDeserialTransfer
    public void setSupplierId(java.lang.Long supplierId) {
        this.supplierId = supplierId;
    }
    /**
     * 供应商名称
     */
    public java.lang.String getSupplierName() {
        return supplierName;
    }

    /**
     * 供应商名称
     */
    public void setSupplierName(java.lang.String supplierName) {
        this.supplierName = supplierName;
    }
    /**
     * 物资名称
     */
    public java.lang.String getMaterialName() {
        return materialName;
    }

    /**
     * 物资名称
     */
    public void setMaterialName(java.lang.String materialName) {
        this.materialName = materialName;
    }
    /**
     * 验收日期
     */
    public java.util.Date getCheckDate() {
        return checkDate;
    }

    /**
     * 验收日期
     */
    public void setCheckDate(java.util.Date checkDate) {
        this.checkDate = checkDate;
    }
    /**
     * 经办人名称
     */
    public java.lang.String getEmployeeName() {
        return employeeName;
    }

    /**
     * 经办人名称
     */
    public void setEmployeeName(java.lang.String employeeName) {
        this.employeeName = employeeName;
    }
    /**
     * 单据状态（审批必须字段）
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态（审批必须字段）
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 创建者主键
     */
    public java.lang.Long getCreateUserId() {
        return createUserId;
    }

    /**
     * 创建者主键
     */
    public void setCreateUserId(java.lang.Long createUserId) {
        this.createUserId = createUserId;
    }
    /**
     * 创建者来源ID
     */
    public java.lang.String getCreateUserSourceId() {
        return createUserSourceId;
    }

    /**
     * 创建者来源ID
     */
    public void setCreateUserSourceId(java.lang.String createUserSourceId) {
        this.createUserSourceId = createUserSourceId;
    }
    /**
     * 创建者名称
     */
    public java.lang.String getCreateUserName() {
        return createUserName;
    }

    /**
     * 创建者名称
     */
    public void setCreateUserName(java.lang.String createUserName) {
        this.createUserName = createUserName;
    }
    /**
     * 工程类型
     */
    public java.lang.Long getEngineeringType() {
        return engineeringType;
    }

    /**
     * 工程类型
     */
    public void setEngineeringType(java.lang.Long engineeringType) {
        this.engineeringType = engineeringType;
    }
    /**
     * 工程类型名称
     */
    public java.lang.String getEngineeringTypeName() {
        return engineeringTypeName;
    }

    /**
     * 工程类型名称
     */
    public void setEngineeringTypeName(java.lang.String engineeringTypeName) {
        this.engineeringTypeName = engineeringTypeName;
    }
    /**
     * 验收类型(0-项目自采,1-内部调拨)
     */
    public java.lang.Integer getCheckType() {
        return checkType;
    }

    /**
     * 验收类型(0-项目自采,1-内部调拨)
     */
    public void setCheckType(java.lang.Integer checkType) {
        this.checkType = checkType;
    }
    /**
     * 工地签收人
     */
    public java.lang.String getSignerName() {
        return signerName;
    }

    /**
     * 工地签收人
     */
    public void setSignerName(java.lang.String signerName) {
        this.signerName = signerName;
    }
    /**
     * 调拨单主键
     */
    public java.lang.Long getAllotId() {
        return allotId;
    }

    /**
     * 调拨单主键
     */
    public void setAllotId(java.lang.Long allotId) {
        this.allotId = allotId;
    }
    /**
     * 验收人
     */
    @ReferSerialTransfer(referCode="idm-employee")
    public java.lang.Long getCheckId() {
        return checkId;
    }

    /**
     * 验收人
     */
    @ReferDeserialTransfer
    public void setCheckId(java.lang.Long checkId) {
        this.checkId = checkId;
    }
    /**
     * 验收人名称
     */
    public java.lang.String getCheckName() {
        return checkName;
    }

    /**
     * 验收人名称
     */
    public void setCheckName(java.lang.String checkName) {
        this.checkName = checkName;
    }
    /**
     * 调拨单编号
     */
    public java.lang.String getAllotCode() {
        return allotCode;
    }

    /**
     * 调拨单编号
     */
    public void setAllotCode(java.lang.String allotCode) {
        this.allotCode = allotCode;
    }
    /**
     * 调出项目
     */
    public java.lang.Long getProjectOutId() {
        return projectOutId;
    }

    /**
     * 调出项目
     */
    public void setProjectOutId(java.lang.Long projectOutId) {
        this.projectOutId = projectOutId;
    }
    /**
     * 调出项目名称
     */
    public java.lang.String getProjectOutName() {
        return projectOutName;
    }

    /**
     * 调出项目名称
     */
    public void setProjectOutName(java.lang.String projectOutName) {
        this.projectOutName = projectOutName;
    }
    /**
     * 类型 0=项目，1=公司
     */
    public java.lang.Integer getBelongType() {
        return belongType;
    }

    /**
     * 类型 0=项目，1=公司
     */
    public void setBelongType(java.lang.Integer belongType) {
        this.belongType = belongType;
    }
    /**
     * 上级组织id
     */
    public java.lang.Long getParentOrgId() {
        return parentOrgId;
    }

    /**
     * 上级组织id
     */
    public void setParentOrgId(java.lang.Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }
    /**
     * 上级组织name
     */
    public java.lang.String getParentOrgName() {
        return parentOrgName;
    }

    /**
     * 上级组织name
     */
    public void setParentOrgName(java.lang.String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }
    @ReferSerialTransfer(referCode="market-project")
    public Long getProjectId() {
        return projectId;
    }

    @ReferDeserialTransfer
    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }
    @ReferSerialTransfer(referCode="idm-employee")
    public Long getEmployeeId() {
        return employeeId;
    }

    @ReferDeserialTransfer
    public void setEmployeeId(Long employeeId) {
        this.employeeId = employeeId;
    }
}
